@@ -534,6 +534,9 @@ class Serializer(object):
                                 xml_name = "{{{}}}{}".format(xml_ns, xml_name)
                             serialized.set(xml_name, new_attr)
                             continue
+                        if xml_desc.get("text", False):
+                            serialized.text = new_attr
+                            continue
                         if isinstance(new_attr, list):
                             serialized.extend(new_attr)
                         elif isinstance(new_attr, ET.Element):
@@ -948,9 +951,11 @@ class Serializer(object):
             return self.serialize_basic(attr, self.basic_types[obj_type], **kwargs)
         if obj_type is _long_type:
             return self.serialize_long(attr)
+        if obj_type is unicode_str:
+            return self.serialize_unicode(attr)
 
         # If it's a model or I know this dependency, serialize as a Model
-        elif obj_type in self.dependencies.values() or isinstance(obj_type, Model):
+        elif obj_type in self.dependencies.values() or isinstance(attr, Model):
             return self._serialize(attr)
 
         if obj_type == dict:
@@ -1247,6 +1252,10 @@ def xml_key_extractor(attr, attr_desc, data):
     if xml_desc.get("attr", False):
         return data.get(xml_name)
 
+    # If it's x-ms-text, that's simple too
+    if xml_desc.get("text", False):
+        return data.text
+
     # Scenario where I take the local name:
     # - Wrapped node
     # - Internal type is an enum (considered basic types)
